summaryrefslogtreecommitdiff
path: root/zsh
diff options
context:
space:
mode:
authorKjetil Ørbekk <kj@orbekk.com>2020-10-22 14:56:02 -0400
committerKjetil Ørbekk <kj@orbekk.com>2020-10-22 14:56:02 -0400
commit3d92655532af89c7ece704db758fe362af6a4f10 (patch)
tree4228ab61105b74dbee0542786f5142dead1a88f6 /zsh
parent4ad95a99d58234202fbaaba89ce0bb63f269aabd (diff)
Update prompt settings
Diffstat (limited to 'zsh')
-rw-r--r--zsh/.zsh/p10k.zsh27
1 files changed, 13 insertions, 14 deletions
diff --git a/zsh/.zsh/p10k.zsh b/zsh/.zsh/p10k.zsh
index 4d95331..ed26027 100644
--- a/zsh/.zsh/p10k.zsh
+++ b/zsh/.zsh/p10k.zsh
@@ -1,7 +1,7 @@
# Generated by Powerlevel10k configuration wizard on 2020-10-22 at 07:26 EDT.
# Based on romkatv/powerlevel10k/config/p10k-lean.zsh.
# Wizard options: powerline, unicode, lean, 2 lines, disconnected, no frame, compact,
# concise, transient_prompt, instant_prompt=verbose.
# Type `p10k configure` to generate another config.
#
# Config for Powerlevel10k with lean prompt style. Type `p10k configure` to generate
@@ -96,7 +96,7 @@
todo # todo items (https://github.com/todotxt/todo.txt-cli)
timewarrior # timewarrior tracking status (https://timewarrior.net/)
taskwarrior # taskwarrior task count (https://taskwarrior.org/)
- # time # current time
+ time # current time
# =========================[ Line #2 ]=========================
newline
# ip # ip address and bandwidth usage for a specified network interface
@@ -108,7 +108,7 @@
)
# Defines character set used by powerlevel10k. It's best to let `p10k configure` set it for you.
- typeset -g POWERLEVEL9K_MODE=powerline
+ typeset -g POWERLEVEL9K_MODE=compatible
# When set to `moderate`, some icons will have an extra space after them. This is meant to avoid
# icon overlap when using non-monospace fonts. When set to `none`, spaces are not added.
typeset -g POWERLEVEL9K_ICON_PADDING=none
@@ -155,7 +155,7 @@
# POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_CHAR=' ' below.
typeset -g POWERLEVEL9K_SHOW_RULER=false
typeset -g POWERLEVEL9K_RULER_CHAR='─' # reasonable alternative: '·'
- typeset -g POWERLEVEL9K_RULER_FOREGROUND=242
+ typeset -g POWERLEVEL9K_RULER_FOREGROUND=244
# Filler between left and right prompt on the first prompt line. You can set it to '·' or '─'
# to make it easier to see the alignment between left and right prompt and to separate prompt
@@ -163,10 +163,10 @@
# the number of prompt lines. You'll probably want to set POWERLEVEL9K_SHOW_RULER=false
# if using this. You might also like POWERLEVEL9K_PROMPT_ADD_NEWLINE=false for more compact
# prompt.
- typeset -g POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_CHAR=' '
+ typeset -g POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_CHAR='─'
if [[ $POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_CHAR != ' ' ]]; then
# The color of the filler.
- typeset -g POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_FOREGROUND=242
+ typeset -g POWERLEVEL9K_MULTILINE_FIRST_PROMPT_GAP_FOREGROUND=244
# Add a space between the end of left prompt and the filler.
typeset -g POWERLEVEL9K_LEFT_PROMPT_LAST_SEGMENT_END_SYMBOL=' '
# Add a space between the filler and the start of right prompt.
@@ -492,23 +492,22 @@
# Status when it's just an error code (e.g., '1'). No need to show it if prompt_char is enabled as
# it will signify error by turning red.
- # But show it anyway.
- typeset -g POWERLEVEL9K_STATUS_ERROR=true
+ typeset -g POWERLEVEL9K_STATUS_ERROR=false
typeset -g POWERLEVEL9K_STATUS_ERROR_FOREGROUND=160
- typeset -g POWERLEVEL9K_STATUS_ERROR_VISUAL_IDENTIFIER_EXPANSION='✘'
+ typeset -g POWERLEVEL9K_STATUS_ERROR_VISUAL_IDENTIFIER_EXPANSION='х'
# Status when the last command was terminated by a signal.
typeset -g POWERLEVEL9K_STATUS_ERROR_SIGNAL=true
typeset -g POWERLEVEL9K_STATUS_ERROR_SIGNAL_FOREGROUND=160
# Use terse signal names: "INT" instead of "SIGINT(2)".
typeset -g POWERLEVEL9K_STATUS_VERBOSE_SIGNAME=false
- typeset -g POWERLEVEL9K_STATUS_ERROR_SIGNAL_VISUAL_IDENTIFIER_EXPANSION='✘'
+ typeset -g POWERLEVEL9K_STATUS_ERROR_SIGNAL_VISUAL_IDENTIFIER_EXPANSION='х'
# Status when some part of a pipe command fails and the overall exit status is also non-zero.
# It may look like this: 1|0.
typeset -g POWERLEVEL9K_STATUS_ERROR_PIPE=true
typeset -g POWERLEVEL9K_STATUS_ERROR_PIPE_FOREGROUND=160
- typeset -g POWERLEVEL9K_STATUS_ERROR_PIPE_VISUAL_IDENTIFIER_EXPANSION='✘'
+ typeset -g POWERLEVEL9K_STATUS_ERROR_PIPE_VISUAL_IDENTIFIER_EXPANSION='х'
###################[ command_execution_time: duration of the last command ]###################
# Show duration of the last command if takes at least this many seconds.
@@ -1,7 +1,7 @@
-# Generated by Powerlevel10k configuration wizard on 2020-10-22 at 07:26 EDT.
-# Based on romkatv/powerlevel10k/config/p10k-lean.zsh.
-# Wizard options: powerline, unicode, lean, 2 lines, disconnected, no frame, compact,
-# concise, transient_prompt, instant_prompt=verbose.
+# Generated by Powerlevel10k configuration wizard on 2020-10-22 at 14:54 EDT.
+# Based on romkatv/powerlevel10k/config/p10k-lean.zsh, checksum 47471.
+# Wizard options: compatible, unicode, lean, 24h time, 2 lines, solid, no frame,
+# lightest-ornaments, compact, concise, transient_prompt, instant_prompt=verbose.
# Type `p10k configure` to generate another config.
#